@@ -5,122 +5,77 @@ from __future__ import absolute_import
 
 # --------------------------------------
 from .vtkCommonCore import *
-from .vtkWebCore import *
 from .vtkCommonMath import *
 from .vtkCommonTransforms import *
 from .vtkCommonDataModel import *
 from .vtkCommonExecutionModel import *
-from .vtkIOCore import *
-from .vtkImagingCore import *
-from .vtkIOImage import *
-from .vtkIOXMLParser import *
-from .vtkIOXML import *
 from .vtkCommonMisc import *
 from .vtkFiltersCore import *
 from .vtkRenderingCore import *
+from .vtkInteractionStyle import *
 from .vtkRenderingContext2D import *
-from .vtkRenderingFreeType import *
-from .vtkRenderingSceneGraph import *
-from .vtkRenderingVtkJS import *
-from .vtkIOExport import *
-from .vtkWebGLExporter import *
 from .vtkFiltersGeneral import *
-from .vtkRenderingHyperTreeGrid import *
-from .vtkRenderingUI import *
-from .vtkRenderingOpenGL2 import *
 from .vtkFiltersSources import *
 from .vtkInteractionWidgets import *
 from .vtkViewsCore import *
-from .vtkInteractionStyle import *
 from .vtkViewsInfovis import *
-from .vtkCommonComputationalGeometry import *
-from .vtkCommonSystem import *
-from .vtkFiltersCellGrid import *
-from .vtkIOCellGrid import *
-from .vtkIOLegacy import *
-from .vtkDomainsChemistry import *
-from .vtkRenderingContextOpenGL2 import *
-from .vtkRenderingVolume import *
-from .vtkImagingMath import *
-from .vtkRenderingVolumeOpenGL2 import *
+from .vtkCommonColor import *
 from .vtkViewsContext2D import *
+from .vtkImagingCore import *
 from .vtkImagingColor import *
+from .vtkIOXMLParser import *
+from .vtkIOXML import *
 from .vtkTestingRendering import *
-from .vtkInteractionImage import *
-from .vtkRenderingRayTracing import *
-from .vtkRenderingVolumeAMR import *
-from .vtkRenderingLabel import *
-from .vtkRenderingQt import *
 from .vtkPythonContext2D import *
-from .vtkParallelCore import *
-from .vtkParallelMPI import *
-from .vtkRenderingLICOpenGL2 import *
-from .vtkRenderingParallelLIC import *
-from .vtkRenderingParallel import *
-from .vtkRenderingVRModels import *
-from .vtkRenderingVR import *
-from .vtkRenderingOpenXR import *
-from .vtkRenderingOpenVR import *
-from .vtkRenderingMatplotlib import *
+from .vtkRenderingFreeType import *
+from .vtkRenderingLabel import *
 from .vtkRenderingLOD import *
+from .vtkIOImage import *
+from .vtkRenderingHyperTreeGrid import *
+from .vtkRenderingUI import *
+from .vtkRenderingOpenGL2 import *
+from .vtkRenderingLICOpenGL2 import *
 from .vtkRenderingImage import *
 from .vtkChartsCore import *
 from .vtkRenderingGridAxes import *
-from .vtkIOMovie import *
-from .vtkIOVideo import *
-from .vtkIOFFMPEG import *
-from .vtkRenderingFFMPEGOpenGL2 import *
-from .vtkRenderingExternal import *
+from .vtkRenderingContextOpenGL2 import *
+from .vtkFiltersCellGrid import *
 from .vtkRenderingCellGrid import *
-from .vtkRenderingAnari import *
-from .vtkParallelMPI4Py import *
-from .vtkIOXdmf2 import *
+from .vtkImagingMath import *
+from .vtkRenderingVolume import *
+from .vtkRenderingVolumeOpenGL2 import *
 from .vtkIOVeraOut import *
-from .vtkIOVPIC import *
 from .vtkIOTecplotTable import *
-from .vtkIOTRUCHAS import *
 from .vtkIOSegY import *
-from .vtkIOSQL import *
-from .vtkIOPostgreSQL import *
-from .vtkIOXdmf3 import *
-from .vtkIOParallelXdmf3 import *
 from .vtkIOParallelXML import *
-from .vtkIONetCDF import *
-from .vtkIOParallelNetCDF import *
-from .vtkIOLSDyna import *
-from .vtkIOParallelLSDyna import *
-from .vtkIOExodus import *
-from .vtkIOParallelExodus import *
+from .vtkIOCore import *
 from .vtkIOPLY import *
-from .vtkIOPIO import *
-from .vtkIOPDAL import *
-from .vtkIOOpenVDB import *
+from .vtkIOMovie import *
 from .vtkIOOggTheora import *
-from .vtkIOOMF import *
-from .vtkIOODBC import *
-from .vtkIOOCCT import *
-from .vtkIOMySQL import *
+from .vtkIONetCDF import *
 from .vtkIOMotionFX import *
+from .vtkIOCellGrid import *
+from .vtkIOLegacy import *
 from .vtkIOGeometry import *
 from .vtkIOParallel import *
-from .vtkIOMPIParallel import *
-from .vtkIOMPIImage import *
 from .vtkIOMINC import *
-from .vtkIOLAS import *
+from .vtkIOLSDyna import *
 from .vtkIOLANLX3D import *
 from .vtkIOImport import *
+from .vtkParallelCore import *
 from .vtkIOIOSS import *
 from .vtkIOHDF import *
-from .vtkIOH5part import *
-from .vtkIOH5Rage import *
-from .vtkIOGeoJSON import *
-from .vtkIOFides import *
 from .vtkIOFLUENTCFF import *
+from .vtkIOVideo import *
 from .vtkIOFDS import *
 from .vtkIOInfovis import *
+from .vtkRenderingSceneGraph import *
+from .vtkRenderingVtkJS import *
+from .vtkIOExport import *
 from .vtkIOExportPDF import *
 from .vtkRenderingGL2PSOpenGL2 import *
 from .vtkIOExportGL2PS import *
+from .vtkIOExodus import *
 from .vtkIOEngys import *
 from .vtkIOEnSight import *
 from .vtkIOERF import *
@@ -129,37 +84,28 @@ from .vtkIOChemistry import *
 from .vtkIOCesium3DTiles import *
 from .vtkIOCONVERGECFD import *
 from .vtkIOCGNSReader import *
-from .vtkIOAvmesh import *
 from .vtkIOAsynchronous import *
-from .vtkIOAlembic import *
 from .vtkIOAMR import *
-from .vtkIOADIOS2 import *
+from .vtkInteractionImage import *
 from .vtkInfovisLayout import *
-from .vtkInfovisBoostGraphAlgorithms import *
 from .vtkImagingStencil import *
 from .vtkImagingStatistics import *
 from .vtkImagingGeneral import *
-from .vtkImagingOpenGL2 import *
 from .vtkImagingMorphological import *
 from .vtkImagingFourier import *
+from .vtkIOSQL import *
 from .vtkRenderingAnnotation import *
 from .vtkImagingHybrid import *
-from .vtkIOGDAL import *
-from .vtkGeovisGDAL import *
 from .vtkGeovisCore import *
 from .vtkFiltersTopology import *
 from .vtkFiltersTensor import *
 from .vtkFiltersSelection import *
 from .vtkFiltersSMP import *
-from .vtkFiltersReebGraph import *
 from .vtkFiltersPython import *
 from .vtkFiltersProgrammable import *
 from .vtkFiltersModeling import *
 from .vtkFiltersPoints import *
-from .vtkFiltersVerdict import *
-from .vtkFiltersParallelVerdict import *
 from .vtkFiltersStatistics import *
-from .vtkFiltersParallelStatistics import *
 from .vtkFiltersImaging import *
 from .vtkFiltersExtraction import *
 from .vtkFiltersGeometry import *
@@ -168,25 +114,19 @@ from .vtkFiltersHyperTree import *
 from .vtkFiltersTexture import *
 from .vtkFiltersParallel import *
 from .vtkFiltersParallelImaging import *
-from .vtkFiltersParallelGeometry import *
-from .vtkFiltersFlowPaths import *
-from .vtkFiltersParallelFlowPaths import *
-from .vtkFiltersParallelDIY2 import *
 from .vtkFiltersTemporal import *
 from .vtkFiltersGeometryPreview import *
 from .vtkFiltersGeneric import *
+from .vtkCommonComputationalGeometry import *
+from .vtkFiltersFlowPaths import *
 from .vtkFiltersAMR import *
-from .vtkDomainsParallelChemistry import *
-from .vtkFiltersParallelMPI import *
+from .vtkDomainsChemistry import *
 from .vtkDomainsChemistryOpenGL2 import *
 from .vtkCommonPython import *
-from .vtkCommonArchive import *
-from .vtkCommonColor import *
 from .vtkImagingSources import *
 from .vtkInfovisCore import *
-from .vtkAcceleratorsVTKmCore import *
-from .vtkAcceleratorsVTKmDataModel import *
-from .vtkAcceleratorsVTKmFilters import *
+from .vtkCommonSystem import *
+from .vtkFiltersVerdict import *
 from .vtkFiltersReduction import *
 
 
